Enum OcmLimited
#[repr(u8)]pub enum OcmLimited {
Show 16 variants
Frozen = 0,
ActiveOnMatch = 1,
InactiveOnMatch = 2,
Toggle = 3,
ForceInactive = 4,
ForceActive = 5,
PwmMode1 = 6,
PwmMode2 = 7,
Reserved1 = 8,
Reserved2 = 9,
Reserved3 = 10,
Reserved4 = 11,
Reserved5 = 12,
Reserved6 = 13,
Reserved7 = 14,
Reserved8 = 15,
}Variants
Frozen = 0
The comparison between the output compare register TIMx_CCRy and the counter TIMx_CNT has no effect on the outputs
ActiveOnMatch = 1
Set channel to active level on match. OCyREF signal is forced high when the counter matches the capture/compare register
InactiveOnMatch = 2
Set channel to inactive level on match. OCyREF signal is forced low when the counter matches the capture/compare register
Toggle = 3
OCyREF toggles when TIMx_CNT=TIMx_CCRy
ForceInactive = 4
OCyREF is forced low
ForceActive = 5
OCyREF is forced high
PwmMode1 = 6
In upcounting, channel is active as long as TIMx_CNT<TIMx_CCRy else inactive. In downcounting, channel is inactive as long as TIMx_CNT>TIMx_CCRy else active
PwmMode2 = 7
Inversely to PwmMode1
Reserved1 = 8
_reserved1
Reserved2 = 9
_reserved2
Reserved3 = 10
_reserved3
Reserved4 = 11
_reserved4
Reserved5 = 12
_reserved5
Reserved6 = 13
_reserved6
Reserved7 = 14
_reserved7
Reserved8 = 15
_reserved8
Implementations
impl OcmLimited
impl OcmLimited
pub const fn from_bits(val: u8) -> OcmLimited
pub const fn to_bits(self) -> u8